@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -184,6 +192,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "CN", "Cina" },
             { "CO", "Colombia" },
             { "CP", "Isola di Clipperton" },
+            { "CQ", "Sark" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Capo Verde" },
@@ -482,7 +491,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "kanuri" },
             { "ks", "kashmiri" },
-            { "ku", "curdo" },
+            { "ku", "kurmancî" },
             { "kv", "komi" },
             { "kw", "cornico" },
             { "ky", "kirghiso" },
@@ -1212,10 +1221,13 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "key.cf", "Formato valuta" },
             { "key.co", "Ordinamento" },
             { "key.cu", "Valuta" },
+            { "key.em", "Presentazione emoji" },
             { "key.hc", "Sistema orario (12 o 24 ore)" },
             { "key.lb", "Tipo di interruzione di riga" },
+            { "key.lw", "Interruzioni di riga all’interno delle parole" },
             { "key.ms", "Sistema di misurazione" },
             { "key.nu", "Numeri" },
+            { "key.ss", "Interruzione frase dopo abbreviaz." },
             { "key.tz", "Fuso orario" },
             { "key.va", "Variante lingua" },
             { "nds_NL", "basso tedesco olandese" },
@@ -1339,7 +1351,6 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "type.ca.iso8601", "Calendario ISO-8601" },
             { "type.ca.persian", "Calendario persiano" },
             { "type.cf.account", "Formato valuta contabile" },
-            { "type.co.big5han", "Ordinamento Cinese tradizionale - Big5" },
             { "type.d0.npinyin", "Numerica" },
             { "type.nu.arabext", "Cifre indo-arabe estese" },
             { "type.nu.armnlow", "Numeri armeni minuscoli" },
@@ -1364,7 +1375,6 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "type.nu.mymrshan", "Cifre shan birmane" },
             { "type.nu.romanlow", "Numeri romani minuscoli" },
             { "type.ca.gregorian", "Calendario gregoriano" },
-            { "type.co.gb2312han", "Ordinamento Cinese semplificato - GB2312" },
             { "type.co.phonebook", "Ordinamento Elenco telefonico" },
             { "type.co.dictionary", "Ordinamento dizionario" },
             { "type.co.traditional", "Ordinamento tradizionale" },
