@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -298,14 +306,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "Ora dell’Amazzonia",
                "",
             };
-        final String[] Anadyr = new String[] {
-               "Ora standard di Anadyr",
-               "",
-               "Ora legale di Anadyr",
-               "",
-               "Ora di Anadyr",
-               "",
-            };
         final String[] Azores = new String[] {
                "Ora standard delle Azzorre",
                "",
@@ -346,6 +346,14 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Hawaii = new String[] {
+               "Ora standard delle Isole Hawaii-Aleutine",
+               "HST",
+               "",
+               "HST",
+               "",
+               "HST",
+            };
         final String[] Israel = new String[] {
                "Ora standard di Israele",
                "IST",
@@ -682,14 +690,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Sakhalin = new String[] {
-               "Ora standard di Sakhalin",
-               "",
-               "Ora legale di Sakhalin",
-               "",
-               "Ora di Sakhalin",
-               "",
-            };
         final String[] Suriname = new String[] {
                "Ora del Suriname",
                "",
@@ -794,14 +794,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Volgograd = new String[] {
-               "Ora standard di Volgograd",
-               "MSK",
-               "Ora legale di Volgograd",
-               "MSK",
-               "Ora di Volgograd",
-               "MSK",
-            };
         final String[] Azerbaijan = new String[] {
                "Ora standard dell’Azerbaigian",
                "",
@@ -890,14 +882,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "Ora della Nuova Zelanda",
                "NZT",
             };
-        final String[] Novosibirsk = new String[] {
-               "Ora standard di Novosibirsk",
-               "",
-               "Ora legale di Novosibirsk",
-               "",
-               "Ora di Novosibirsk",
-               "",
-            };
         final String[] Philippines = new String[] {
                "Ora standard delle Filippine",
                "PST",
@@ -995,12 +979,12 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "EAT",
             };
         final String[] Africa_Western = new String[] {
-               "Ora standard dell’Africa occidentale",
-               "WAT",
-               "Ora legale dell’Africa occidentale",
-               "WAT",
                "Ora dell’Africa occidentale",
                "WAT",
+               "",
+               "WAT",
+               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Ora di Dumont-d’Urville",
@@ -1094,9 +1078,9 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                "Ora standard delle Isole Hawaii-Aleutine",
                "HST",
                "Ora legale delle Isole Hawaii-Aleutine",
-               "HST",
+               "HDT",
                "Ora delle isole Hawaii-Aleutine",
-               "HST",
+               "HT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Ora delle Isole della Fenice",
@@ -1201,7 +1185,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
+            { "Pacific/Honolulu", Hawaii },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -1240,7 +1224,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "EET", Europe_Eastern },
             { "EST", America_Eastern },
-            { "HST", Hawaii_Aleutian },
+            { "HST", Hawaii },
             { "IET", America_Eastern },
             { "IST", India },
             { "JST", Japan },
@@ -1354,7 +1338,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Kwajalein", Marshall_Islands },
             { "Singapore", Singapore },
             { "US/Alaska", Alaska },
-            { "US/Hawaii", Hawaii_Aleutian },
+            { "US/Hawaii", Hawaii },
             { "Universal",
                 new String[] {
                     "Tempo coordinato universale",
@@ -1375,6 +1359,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "Asia/Tomsk", Krasnoyarsk },
             { "US/Arizona", America_Mountain },
             { "US/Central", America_Central },
             { "US/Eastern", America_Eastern },
@@ -1382,7 +1367,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan },
-            { "Asia/Anadyr", Anadyr },
+            { "Asia/Anadyr", Kamchatka },
             { "Asia/Aqtobe", Kazakhstan },
             { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
@@ -1423,6 +1408,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Baghdad", Arabian },
             { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
+            { "Asia/Barnaul", Krasnoyarsk },
             { "Asia/Bishkek", Kyrgystan },
             { "Asia/Colombo", India },
             { "Asia/Irkutsk", Irkutsk },
@@ -1438,6 +1424,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
             { "Canada/Yukon", Yukon },
+            { "Europe/Kirov", Moscow },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1484,7 +1471,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
             { "Asia/Qostanay", Kazakhstan },
-            { "Asia/Sakhalin", Sakhalin },
+            { "Asia/Sakhalin", Magadan },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
@@ -1553,7 +1540,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
             { "Pacific/Samoa", Samoa },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "SystemV/HST10", Hawaii },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1583,6 +1570,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
             { "Asia/Chungking", China },
+            { "Asia/Famagusta", Europe_Eastern },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
             { "Asia/Kathmandu", Nepal },
@@ -1609,6 +1597,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
                 }
             },
             { "Europe/Nicosia", Europe_Eastern },
+            { "Europe/Saratov", Samara },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
@@ -1728,7 +1717,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Antarctica/Troll", GMT },
             { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
-            { "Asia/Novosibirsk", Novosibirsk },
+            { "Asia/Novosibirsk", Krasnoyarsk },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Vladivostok", Vladivostok },
             { "Atlantic/Bermuda", Atlantic },
@@ -1740,19 +1729,21 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "Australia/Sydney", Australia_Eastern },
             { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Astrakhan", Samara },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
-            { "Europe/Volgograd", Volgograd },
+            { "Europe/Ulyanovsk", Samara },
+            { "Europe/Volgograd", Moscow },
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
             { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston", Hawaii },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1810,6 +1801,7 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Srednekolymsk", Magadan },
             { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
@@ -1904,7 +1896,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Africa/Juba", "Giuba" },
-            { "timezone.excity.Africa/Lome", "Lomé" },
             { "timezone.excity.Asia/Anadyr", "Anadyr’" },
             { "timezone.excity.Asia/Aqtobe", "Aqtöbe" },
             { "timezone.excity.Asia/Muscat", "Mascate" },
@@ -1934,7 +1925,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/London", "Londra" },
             { "timezone.excity.Europe/Moscow", "Mosca" },
             { "timezone.excity.Europe/Prague", "Praga" },
-            { "timezone.excity.Europe/Tirane", "Tirana" },
             { "timezone.excity.Europe/Warsaw", "Varsavia" },
             { "timezone.excity.Europe/Zagreb", "Zagabria" },
             { "timezone.excity.Europe/Zurich", "Zurigo" },
@@ -1943,7 +1933,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Algeri" },
-            { "timezone.excity.America/Bogota", "Bogotá" },
             { "timezone.excity.America/Havana", "L’Avana" },
             { "timezone.excity.Asia/Famagusta", "Famagosta" },
             { "timezone.excity.Asia/Jerusalem", "Gerusalemme" },
@@ -1951,11 +1940,9 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Vatican", "Città del Vaticano" },
             { "timezone.excity.Indian/Reunion", "La Riunione" },
             { "timezone.excity.Pacific/Easter", "Pasqua" },
-            { "timezone.excity.Pacific/Kanton", "Canton" },
             { "timezone.excity.Africa/Djibouti", "Gibuti" },
             { "timezone.excity.Africa/El_Aaiun", "El Ayun" },
             { "timezone.excity.Africa/Khartoum", "Khartum" },
-            { "timezone.excity.Africa/Ndjamena", "N’Djamena" },
             { "timezone.excity.America/Cayenne", "Caienna" },
             { "timezone.excity.America/Jamaica", "Giamaica" },
             { "timezone.excity.Atlantic/Azores", "Azzorre" },
@@ -1963,10 +1950,8 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Faeroe", "Isole Fær Øer" },
             { "timezone.excity.Europe/Belgrade", "Belgrado" },
             { "timezone.excity.Europe/Brussels", "Bruxelles" },
-            { "timezone.excity.Europe/Busingen", "Büsingen" },
             { "timezone.excity.Indian/Maldives", "Maldive" },
             { "timezone.excity.Africa/Mogadishu", "Mogadiscio" },
-            { "timezone.excity.America/Santarem", "Santarém" },
             { "timezone.excity.America/St_Lucia", "Santa Lucia" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ulan Bator" },
@@ -1981,7 +1966,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Copenhagen", "Copenaghen" },
             { "timezone.excity.Europe/Luxembourg", "Lussemburgo" },
             { "timezone.excity.Europe/Simferopol", "Sinferopoli" },
-            { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Marquesas", "Marchesi" },
             { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
             { "timezone.excity.America/Guadeloupe", "Guadalupa" },
@@ -1996,7 +1980,6 @@ public class TimeZoneNames_it extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Cape_Verde", "Capo Verde" },
             { "timezone.excity.America/St_Barthelemy", "Saint-Barthélemy" },
             { "timezone.excity.Atlantic/South_Georgia", "Georgia del Sud" },
-            { "timezone.excity.America/Argentina/Tucuman", "Tucumán" },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Dakota del nord" },
             { "timezone.excity.America/North_Dakota/Center", "Center, Dakota del nord" },
             { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota del nord" },
